class MetadataNotFound(Exception):
    pass


class MetadataCorruption(Exception):
    pass


class NotYetImplemented(Exception):
    pass


class SPConfigurationMissing(Exception):
    pass


class UnavailableRequiredAttributes(Exception):
    pass


class DisabledSP(Exception):
    pass
